@@ -32,7 +32,7 @@
 
 #include <liblepton/liblepton.h>
 #include <liblepton/libgedaguile.h>
-#include <libleptonrenderer/libleptonrenderer.h>
+#include <liblepton/libleptonrenderer.h>
 
 #include <gtk/gtk.h>
 #include <glib/gstdio.h>
@@ -146,7 +146,7 @@ static struct ExportSettings settings = {
 static void
 cmd_export_impl (void *data, int argc, char **argv)
 {
-  int i;
+  size_t i;
   GError *err = NULL;
   gchar *tmp;
   const gchar *out_suffix;
@@ -168,7 +168,7 @@ cmd_export_impl (void *data, int argc, char **argv)
 
   /* Now load rc files, if necessary */
   if (getenv ("LEPTON_INHIBIT_RC_FILES") == NULL) {
-    g_rc_parse (toplevel, "lepton-cli export", NULL, NULL);
+    g_rc_parse ("lepton-cli export", NULL, NULL);
   }
 
   /* Parse configuration files */
@@ -231,15 +231,16 @@ cmd_export_impl (void *data, int argc, char **argv)
 
   /* Create color map */
   render_color_map =
-    g_array_sized_new (FALSE, FALSE, sizeof(GedaColor), MAX_COLORS);
+    g_array_sized_new (FALSE, FALSE, sizeof(GedaColor), colors_count());
+  GedaColor* print_colors = print_colors_array();
   render_color_map =
-    g_array_append_vals (render_color_map, print_colors, MAX_COLORS);
+    g_array_append_vals (render_color_map, print_colors, colors_count());
   if (!settings.color) {
     /* Create a black and white color map.  All non-background colors
      * are black. */
     GedaColor white = {255, 255, 255, 255, TRUE};
     GedaColor black = {0, 0, 0, 255, TRUE};
-    for (i = 0; i < MAX_COLORS; i++) {
+    for (i = 0; i < colors_count(); i++) {
       GedaColor *c = &g_array_index (render_color_map, GedaColor, i);
       if (!c->enabled) continue;
 
