@@ -353,18 +353,18 @@ o_pin_read (const char buf[],
   }
 
   if (whichend == -1) {
-    s_log_message (_("Found a pin which did not have the whichend field set.\n"
-                     "Verify and correct manually."));
+    g_message (_("Found a pin which did not have the whichend field set.\n"
+                 "Verify and correct manually."));
   } else if (whichend < -1 || whichend > 1) {
-    s_log_message (_("Found an invalid whichend on a pin (reseting to zero): %d"),
-                   whichend);
+    g_message (_("Found an invalid whichend on a pin (reseting to zero): %d"),
+               whichend);
     whichend = 0;
   }
 
-  if (color < 0 || color > MAX_COLORS) {
-    s_log_message (_("Found an invalid color [ %1$s ]"), buf);
-    s_log_message (_("Setting color to default color."));
-    color = DEFAULT_COLOR;
+  if (!color_id_valid (color)) {
+    g_message (_("Found an invalid color [ %1$s ]"), buf);
+    g_message (_("Setting color to default color."));
+    color = default_color_id();
   }
 
   new_obj = geda_pin_object_new (color,
