@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 /*!
@@ -298,9 +298,7 @@ smob_free (SCM smob)
                  __FUNCTION__, data);
       break;
     case GEDA_SMOB_OBJECT:
-      /* See edascm_from_object() for an explanation of why OBJECT
-       * smobs store a TOPLEVEL in the second data word */
-      s_delete_object ((TOPLEVEL *) SCM_SMOB_DATA_2 (smob), (OBJECT *) data);
+      s_delete_object ((OBJECT *) data);
       break;
     case GEDA_SMOB_CONFIG:
       /* These are reference counted, so the structure will have
@@ -378,6 +376,7 @@ smob_print (SCM smob, SCM port, scm_print_state *pstate)
 static SCM
 smob_equalp (SCM obj1, SCM obj2)
 {
+  g_debug ("smob_equalp()\n");
   EDASCM_ASSERT_SMOB_VALID (obj1);
   EDASCM_ASSERT_SMOB_VALID (obj2);
 
@@ -457,6 +456,7 @@ edascm_from_page (PAGE *page)
 PAGE *
 edascm_to_page (SCM smob)
 {
+  g_debug ("edascm_to_page()\n");
 #ifndef NDEBUG
   SCM_ASSERT (EDASCM_PAGEP (smob), smob,
               SCM_ARG1, "edascm_to_page");
@@ -523,6 +523,7 @@ edascm_from_object (OBJECT *object)
 OBJECT *
 edascm_to_object (SCM smob)
 {
+  g_debug ("edascm_to_object()\n");
 #ifndef NDEBUG
   SCM_ASSERT (EDASCM_OBJECTP (smob), smob,
               SCM_ARG1, "edascm_to_object");
@@ -565,6 +566,7 @@ edascm_from_config (EdaConfig *cfg)
 EdaConfig *
 edascm_to_config (SCM smob)
 {
+  g_debug ("edascm_to_config()\n");
 #ifndef NDEBUG
   SCM_ASSERT (EDASCM_CONFIGP (smob), smob,
               SCM_ARG1, "edascm_to_object");
@@ -607,6 +609,7 @@ edascm_from_closure (SCM (*func)(SCM, gpointer), gpointer user_data)
 void
 edascm_c_set_gc (SCM smob, int gc)
 {
+  g_debug ("edascm_c_set_gc()\n");
   EDASCM_ASSERT_SMOB_VALID (smob);
   int current = EDASCM_SMOB_GCP (smob);
 
